--
--                      This file is part of Qucsada
--
--  The MIT License (MIT)
--
--  Copyright (c) 2013 Riccardo Bernardini framefritti@gmail.com
--
--  Permission is hereby granted, free of charge, to any person obtaining a copy
--  of this software and associated documentation files (the "Software"), to deal
--  in the Software without restriction, including without limitation the rights
--  to use, copy, modify, merge, publish, distribute, sublicense, and/or sell
--  copies of the Software, and to permit persons to whom the Software is
--  furnished to do so, subject to the following conditions:
--
--  The above copyright notice and this permission notice shall be included in
--  all copies or substantial portions of the Software.
--
--  THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR
--  IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
--  FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE
--  AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER
--  LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM,
--  OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN
--  THE SOFTWARE.


package QUCS is
   --
   --  -------------------
   --  ** What is this? **
   --  -------------------
   --
   --  This hierarchy provides types and subprograms to read the data
   --  files produced by Qucs (an open source circuit simulator, see
   --  http://qucs.sourceforge.net/) as result of a simulation.
   --
   --  The most important packages in the hierarchy are
   --
   --    [Qucs.Variables]
   --        Provides types representing a single "variable" stored
   --        n a Qucs file
   --
   --    [Qucs.Datasets]
   --        A dataset is a collection of Qucs variables.  In other words,
   --        it is an abstraction of the file content.
   --
   --    [Qucs.Datasets.IO]
   --        The actual I/O functions.
   --
   --  ----------------------
   --  ** How do I use it? **
   --  ----------------------
   --
   --  Really simple: just call the function Load in Qucs.Datasets.IO; for
   --  example
   --
   --      Loaded_Data := Qucs.Datasets.IO.Load(Filename);
   --
   --  Now you can access the content of Loaded_Data by using the functions
   --  in Qucs.Datasets and Qucs.Variables

end QUCS;
